.. sphinx-llm documentation master file, created by
   sphinx-quickstart on Thu Nov 28 09:52:02 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sphinx-llm's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   test
   apples
   nested/example


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
